@@ -56,7 +56,7 @@ static int get_match(const char *input, const char *pattern, char **match)
     if (ret)
     {
         regerror(ret, &re, err, sizeof(err));
-        printf("reg error: %s\n", err);
+        fprintf(stderr, "regex error: %s", err);
         return ret;
     }
 
@@ -152,19 +152,24 @@ static int data_handler(void *user, const char *section, const char *name,
         {
             option.color = atoi(value);
         }
+        else if (!strcmp(name, "socket"))
+        {
+            asprintf(&c->socket, "%s", value);
+            option.socket = c->socket;
+        }
     }
     return 0;
 }
 
 /**
- * section_search_handler() - walk config file to find section matching user input
+ * section_pattern_search_handler() - walk config file to find section matching user input
  *
  * INIH handler used to resolve the section matching the user's input.
  * This will look for the pattern element of each section and try to match it
  * with the user input.
  */
-static int section_search_handler(void *user, const char *section, const char
-                                  *varname, const char *varval)
+static int section_pattern_search_handler(void *user, const char *section, const char *varname,
+                                          const char *varval)
 {
     UNUSED(user);
 
@@ -185,6 +190,28 @@ static int section_search_handler(void *user, const char *section, const char
     return 0;
 }
 
+/**
+ * section_pattern_search_handler() - walk config file to find section matching user input
+ *
+ * INIH handler used to resolve the section matching the user's input.
+ * This will try to match the user input against a section with the name of the user input.
+ */
+static int section_name_search_handler(void *user, const char *section, const char *varname,
+                                       const char *varval)
+{
+    UNUSED(user);
+    UNUSED(varname);
+    UNUSED(varval);
+
+    if (!strcmp(section, c->user))
+    {
+        /* section name matches as plain text */
+        asprintf(&c->section_name, "%s", section);
+    }
+
+    return 0;
+}
+
 static int resolve_config_file(void)
 {
     asprintf(&c->path, "%s/tio/tiorc", getenv("XDG_CONFIG_HOME"));
@@ -216,7 +243,12 @@ void config_file_parse(const int argc, char *argv[])
     c = malloc(sizeof(struct config_t));
     memset(c, 0, sizeof(struct config_t));
 
-    resolve_config_file();
+    // Find config file
+    if (resolve_config_file() != 0)
+    {
+        // None found - stop parsing
+        return;
+    }
 
     for (i = 1; i < argc; i++)
     {
@@ -232,17 +264,33 @@ void config_file_parse(const int argc, char *argv[])
         return;
     }
 
-    ret = ini_parse(c->path, section_search_handler, NULL);
-    if (!c->section_name)
-    {
-        debug_printf("unable to match user input to configuration section (%d)\n", ret);
-        return;
-    }
-
+    // Parse default (unnamed) settings
+    asprintf(&c->section_name, "%s", "");
     ret = ini_parse(c->path, data_handler, NULL);
     if (ret < 0)
     {
-        fprintf(stderr, "Error: unable to parse configuration file (%d)\n", ret);
+        fprintf(stderr, "Error: Unable to parse configuration file (%d)", ret);
+        exit(EXIT_FAILURE);
+    }
+    c->section_name = NULL;
+
+    // Find matching section
+    ret = ini_parse(c->path, section_pattern_search_handler, NULL);
+    if (!c->section_name)
+    {
+        ret = ini_parse(c->path, section_name_search_handler, NULL);
+        if (!c->section_name)
+        {
+            debug_printf("Unable to match user input to configuration section (%d)", ret);
+            return;
+        }
+    }
+
+    // Parse settings of found section
+    ret = ini_parse(c->path, data_handler, NULL);
+    if (ret < 0)
+    {
+        fprintf(stderr, "Error: Unable to parse configuration file (%d)", ret);
         exit(EXIT_FAILURE);
     }
 }
