@@ -30,6 +30,7 @@
 #include "error.h"
 #include "print.h"
 #include "signals.h"
+#include "socket.h"
 
 int main(int argc, char *argv[])
 {
@@ -78,6 +79,9 @@ int main(int argc, char *argv[])
     tio_printf("tio v%s", VERSION);
     tio_printf("Press ctrl-t q to quit");
 
+    /* Open socket */
+    socket_configure();
+
     /* Connect to tty device */
     if (option.no_autoconnect)
         status = tty_connect();
